Full API
=========

Core
----

Fields
~~~~~~

.. automodule:: hcipy.field
	:members:
	:undoc-members:
	:show-inheritance:

Mode bases
~~~~~~~~~~

.. automodule:: hcipy.mode_basis
	:members:
	:undoc-members:
	:show-inheritance:

Fourier transforms
~~~~~~~~~~~~~~~~~~

.. automodule:: hcipy.fourier
	:members:
	:undoc-members:
	:show-inheritance:

Optical systems
~~~~~~~~~~~~~~~

.. automodule:: hcipy.optics
	:members:
	:undoc-members:
	:show-inheritance:

.. automodule:: hcipy.propagation
	:members:
	:undoc-members:
	:show-inheritance:

.. automodule:: hcipy.aperture
	:members:
	:undoc-members:
	:show-inheritance:

Adaptive optics
---------------

Atmospheric model
~~~~~~~~~~~~~~~~~

.. automodule:: hcipy.atmosphere
	:members:
	:undoc-members:
	:show-inheritance:

Wavefront sensing
~~~~~~~~~~~~~~~~~

.. automodule:: hcipy.wavefront_sensing
	:members:
	:undoc-members:
	:show-inheritance:

Wavefront control
~~~~~~~~~~~~~~~~~

.. automodule:: hcipy.wavefront_control
	:members:
	:undoc-members:
	:show-inheritance:

Coronagraphy
------------

.. automodule:: hcipy.coronagraphy
	:members:
	:undoc-members:
	:show-inheritance:

Data reduction
--------------

Miscellaneous
-------------

Math utilities
~~~~~~~~~~~~~~

.. automodule:: hcipy.math_util
	:members:
	:undoc-members:
	:show-inheritance:

Interpolation
~~~~~~~~~~~~~

.. automodule:: hcipy.interpolation
	:members:
	:undoc-members:
	:show-inheritance:

Metrics
~~~~~~~

.. automodule:: hcipy.metrics
	:members:
	:undoc-members:
	:show-inheritance:

Plotting
~~~~~~~~

.. automodule:: hcipy.plotting
	:members:
	:undoc-members:
	:show-inheritance:

Statistics
~~~~~~~~~~

.. automodule:: hcipy.statistics
	:members:
	:undoc-members:
	:show-inheritance:

Techniques
~~~~~~~~~~

.. automodule:: hcipy.techniques
	:members:
	:undoc-members:
	:show-inheritance:
